@@ -2,11 +2,13 @@ from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.common.by import By
 from selenium.common import exceptions as SeleniumExceptions
+import undetected_chromedriver as uc
 
 from requests.adapters import HTTPAdapter
 from datetime import datetime, timedelta
-import undetected_chromedriver as uc
+from urllib.parse import unquote
 import requests
+import base64
 import uuid
 import json
 import re
@@ -59,7 +61,7 @@ class ChatGPT:
         self.session.proxies = {'http': proxy, 'https': proxy} if self.proxy else {}
         self.session.mount('https://chat.openai.com', HTTPAdapter(max_retries=5))
 
-        self.__last_cf = None
+        self.last_cf = None
         self.cf_refresh_interval = cf_refresh_interval
         self.session_token = session_token
         if not self.session_token:
@@ -77,7 +79,7 @@ class ChatGPT:
         Get the Cloudflare cookies & user-agent
         '''
         # Don't refresh the cf cookies if they are less than 30 minutes old
-        if self.__last_cf and datetime.now() - self.__last_cf < timedelta(
+        if self.last_cf and datetime.now() - self.last_cf < timedelta(
             minutes=self.cf_refresh_interval
         ):
             return
@@ -129,7 +131,7 @@ class ChatGPT:
         ]
         for cookie in self.cookies:
             self.session.cookies.set(cookie['name'], cookie['value'])
-        self.__last_cf = datetime.now()
+        self.last_cf = datetime.now()
 
         # Close the browser
         self.driver.quit()
@@ -163,8 +165,19 @@ class ChatGPT:
         resp = self.session.get(redirect_url)
         if resp.status_code != 200:
             raise ValueError(f'Status code {resp.status_code}: {resp.text}')
+
+        captcha = None
         if '<img alt="captcha"' in resp.text:
-            raise ValueError('Captcha detected')
+            try:
+                import svg_captcha_solver
+            except ModuleNotFoundError:
+                raise ModuleNotFoundError(
+                    'Please install svg_captcha_solver to solve captchas: pip install https://github.com/dinhitcom/svg-captcha-solver/archive/master.zip'
+                )
+            captcha_src = re.findall(r'<img alt="captcha" src="([^"]+)"', resp.text)[0]
+            svg = base64.b64decode(captcha_src.split(',')[1])
+            captcha = svg_captcha_solver.solve_captcha(svg)
+
         pattern = r'<input type="hidden" name="state" value="(.*)" \/>'
         results = re.findall(pattern, resp.text)
         if not results:
@@ -172,17 +185,20 @@ class ChatGPT:
         state = results[0]
 
         # Post email
+        payload = {
+            'state': state,
+            'username': email,
+            'js-available': 'true',
+            'webauthn-available': 'true',
+            'is-brave': 'false',
+            'webauthn-platform-available': 'false',
+            'action': 'default',
+        }
+        if captcha:
+            payload['captcha'] = captcha
         resp = self.session.post(
             f'https://auth0.openai.com/u/login/identifier?state={state}',
-            data={
-                'state': state,
-                'username': email,
-                'js-available': 'false',
-                'webauthn-available': 'true',
-                'is-brave': 'false',
-                'webauthn-platform-available': 'false',
-                'action': 'default',
-            },
+            data=payload,
         )
         if resp.status_code != 200:
             raise ValueError(f'Status code {resp.status_code}: {resp.text}')
@@ -203,7 +219,9 @@ class ChatGPT:
         # Get session token in CookieJar
         cookies = self.session.cookies.get_dict()
         if '__Secure-next-auth.session-token' not in cookies:
-            raise ValueError(f'Could not get session token: {cookies}')
+            if resp.url.startswith('https://chat.openai.com/auth/error?error='):
+                raise ValueError(unquote(resp.url.split('error=')[1]))
+            raise ValueError(f'Could not get session token: {resp.text}')
         return cookies['__Secure-next-auth.session-token']
 
     def __refresh_auth(self) -> None:
